##  4. How do I configure a Portal in SAP LeanIX?
To configure a Portal in SAP LeanIX you simply have to go to Administration > Self Service Portal. Select New Portal to create a new portal, or click on an existing portal name, to edit an existing portal.
For more information, see [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.").
